.. _installation:

Installation
============

Currently, only the installation via pip is supported, the installation through conda hopefully follows soon.
The package is exclusively written in python and supports python version 3.6 and above.

To install the package via pip, simply type

.. code-block:: bash

    pip install gammaALPs

The following packages are required and will be installed (if not already present):

 * numpy
 * scipy
 * astropy
 * numba
 * ebltable

The `ebltable package <https://github.com/me-manu/ebltable/>`_ is a small package for the interpolation and
calculation of the absorption of gamma rays on the extragalactic background light (EBL) and can be installed using pip,

.. code-block:: bash

    pip install ebltable
